<?php
print (basename(__FILE__).": Init...\n");

// Change directory
@chdir("..");

// Load config file
require(dirname(dirname(__FILE__)) . '/inc/config.php');

// Load all include files
require($cfg->readConfig('base_path') . 'inc/includes.php');

// Load all game classes
require($cfg->readConfig('base_path') . 'inc/classes.php');

// Set default application
FrameworkConfiguration::getInstance()->setConfigEntry('default_application', 'ship-simu');

// Set testing mode (no starter.php will be loaded!)
define('TEST_MODE', true);

// Load the PHPUnit framework
require_once('PHPUnit/Framework.php');

print (basename(__FILE__).": Init completed.\n\n");

/**
 * A test case for the registry
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 * @see			http://www.phpunit.de
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class RegistryTest extends PHPUnit_Framework_TestCase {
	/**
	 * Tests if we can store an instance to the registry
	 *
	 * @return void
	 */
	public function testInstanceRegistryAdd () {
		// Get a registry instance
		$registryInstance = Registry::getRegistry();

		// Create a User instance
		$userInstance = Member::createMemberByEmail("webmaster@ship-simu.org");

		// Now store the instance in the registry
		$registryInstance->addInstance('user', $userInstance);

		// Test if the registry key is there
		if (!$registryInstance->instanceExists('user')) {
			$this->fail("Registry test failed: Cannot locate our user instance in registry!");
		}
	}

	/**
	 * Tests if we can store an instance to the registry
	 *
	 * @return void
	 */
	public function testInstanceRegistryCompare () {
		// Get a registry instance
		$registryInstance = Registry::getRegistry();

		// And get it back
		$userInstance = $registryInstance->getInstance('user');

		// Compare both unique keys
		$testPassed = ($userInstance instanceof ManageableAccount);

		// Test passed?
		if (!$testPassed) {
			$this->fail("Registry test failed: Method getInstance() returned a non-object.");
		}
	}
}

?>
